@@ -1,3 +1,4 @@
+from CyberSource.logging.log_configuration import LogConfiguration
 from authenticationsdk.util.GlobalLabelParameters import *
 from wsgiref.handlers import format_date_time
 from datetime import datetime
@@ -6,7 +7,7 @@ import ast
 import json
 import authenticationsdk.util.ExceptionAuth
 import os
-import authenticationsdk.logger.Log
+import CyberSource.logging.log_factory as LogFactory
 
 
 class MerchantConfiguration:
@@ -38,17 +39,14 @@ class MerchantConfiguration:
         self.refresh_token = None
         self.response_code = None
         self.response_message = None
-        self.v_c_correlation_id = None
-        self.enable_log = None
-        self.maximum_size = None
-        self.log_directory = None
-        self.log_file_name = None
+        self.v_c_correlation_id = None        
         self.proxy_address = None
         self.proxy_port = None
         self.key_file_name = None
-        self.request_json_path_data = None
-        self.log = None
+        self.request_json_path_data = None        
         self.solution_id = None
+        self.log_config = None
+        self.logger = LogFactory.setup_logger(self.__class__.__name__)
 
     def set_merchant_keyid(self, value):
         if not (value.get('merchant_keyid') is None):
@@ -62,12 +60,6 @@ class MerchantConfiguration:
         if not (value.get('keys_directory') is None):
             self.key_file_path = value['keys_directory']
 
-    def set_log_file_name(self, value):
-        if not (value.get('log_file_name') is None or value.get('log_file_name') == ""):
-            self.log_file_name = value['log_file_name']
-        else:
-            self.log_file_name = GlobalLabelParameters.LOG_FILE_NAME_DEFAULT
-
     def set_key_alias(self, value):
         if not (value.get('key_alias') is None):
             self.key_alias = value['key_alias']
@@ -94,30 +86,6 @@ class MerchantConfiguration:
         if not (value.get('portfolio_id') is None):
             self.portfolio_id = value['portfolio_id']
 
-    def set_enable_log(self, value):
-
-        if not (value.get('enable_log') == "" or value.get('enable_log') is None):
-            self.enable_log = value['enable_log']
-        else:
-            self.enable_log = GlobalLabelParameters.DEFAULT_ENABLE_LOG
-
-    def set_maximum_size(self, value):
-
-        if not (value.get('log_maximum_size') == "" or value.get('log_maximum_size') is None):
-            self.maximum_size = value['log_maximum_size']
-        else:
-            self.maximum_size = GlobalLabelParameters.DEFAULT_MAXIMUM_SIZE  # 10 MB = 10485760 bytes
-
-    def set_log_directory(self, value):
-
-        if not (value.get('log_directory') == "" or value.get('log_directory') is None):
-            if os.path.exists(value['log_directory']) or os.path.isdir(value['log_directory']):
-                self.log_directory = value['log_directory']
-            else:
-                self.log_directory = GlobalLabelParameters.DEFAULT_LOG_DIRECTORY
-        else:
-            self.log_directory = GlobalLabelParameters.DEFAULT_LOG_DIRECTORY
-
     def set_run_environment(self, value):
         if not (value.get('run_environment') is None):
             self.run_environment = value['run_environment']
@@ -184,6 +152,11 @@ class MerchantConfiguration:
         if not (value.get('refresh_token') is None):
             self.refresh_token = value['refresh_token']
 
+    def set_log_configuration(self, value):
+        self.log_config = LogConfiguration()
+        if not (value.get('log_config') is None):
+            self.log_config = value['log_config']
+
 
     # This method sets the Merchant Configuration Variables to its respective values after reading from cybs.properties
     def set_merchantconfig(self, val):
@@ -199,11 +172,7 @@ class MerchantConfiguration:
         self.set_run_environment(val)
         self.set_merchant_id(val)
         self.set_authentication_type(val)
-        self.set_enable_log(val)
-        self.set_maximum_size(val)
-        self.set_log_directory(val)
         self.set_request_host(val)
-        self.set_log_file_name(val)
         self.set_proxy_address(val)
         self.set_proxy_port(val)
         self.set_enable_client_cert(val)
@@ -215,6 +184,7 @@ class MerchantConfiguration:
         self.set_client_secret(val)
         self.set_access_token(val)
         self.set_refresh_token(val)
+        self.set_log_configuration(val)
 
     # Returns the time in format as defined by RFC7231
     def get_time(self):
@@ -224,67 +194,40 @@ class MerchantConfiguration:
         return format_date_time(stamp)
 
     # This validates the Merchant details
-    def validate_merchant_details(self, details, mconfig):
+    def validate_merchant_details(self, details, mconfig = None):
         # verify Mandatory Properties
-        logger = authenticationsdk.logger.Log.setup_logger(mconfig)
-        mconfig.log = logger
-        if self.enable_log is True:
-            logger.info("START> ======================================= ")       
+        self.logger = LogFactory.setup_logger(self.__class__.__name__, self.log_config)
+        if self.log_config.enable_log is True:
+            self.logger.info("START> ======================================= ")       
 
         if self.authentication_type is None or self.authentication_type == "":
-            authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+            authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                GlobalLabelParameters.AUTHENTICATION_REQ,
-                                                                               mconfig)
+                                                                               self.log_config)
 
         if self.run_environment is None or self.run_environment == "":
-            authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+            authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                GlobalLabelParameters.RUN_ENVIRONMENT_EMPTY,
-                                                                               mconfig)
-
-        # Fallback for missing values
-        if details.get('enable_log') is None or details.get('enable_log') == "":
-            authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
-                                                                         GlobalLabelParameters.ENABLE_LOG_DEFAULT_MESSAGE,
-                                                                         mconfig)
-
-        if details.get('log_maximum_size') is None or details.get('log_maximum_size') == "":
-            authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
-                                                                         GlobalLabelParameters.LOG_MAXIMUM_SIZE_DEFAULT_MESSAGE,
-                                                                         mconfig)
-        if details.get('log_file_name') is None or details.get('log_file_name') == "":
-            authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
-                                                                         GlobalLabelParameters.DEFAULT_LOG_FILE_NAME,
-                                                                         mconfig)
-
-        if details.get('log_directory') is None or details.get('log_directory') == "":
-            authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
-                                                                         GlobalLabelParameters.LOG_DIRECTORY_DEFAULT_MESSAGE,
-                                                                         mconfig)
-        elif not (os.path.exists(details.get('log_directory')) or os.path.isdir(details.get('log_directory'))):
-
-            authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
-                                                                         GlobalLabelParameters.LOG_DIRECTORY_INCORRECT_MESSAGE,
-                                                                         mconfig)
-
+                                                                               self.log_config)
 
         if self.use_metakey and (self.portfolio_id is None or self.portfolio_id == ""):
-            authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger, GlobalLabelParameters.PORTFOLIO_ID_REQ, mconfig)
+            authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger, GlobalLabelParameters.PORTFOLIO_ID_REQ, self.log_config)
 
         if self.enable_client_cert is not None and self.enable_client_cert:
             if self.client_cert_dir is None or self.client_cert_dir == "":
-                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                GlobalLabelParameters.CLIENT_CERT_DIR_EMPTY,
-                                                                               mconfig)
+                                                                               self.log_config)
             
             if self.ssl_client_cert is None or self.ssl_client_cert == "":
-                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                GlobalLabelParameters.SSL_CLIENT_CERT_EMPTY,
-                                                                               mconfig)
+                                                                               self.log_config)
             
             if self.private_key is None or self.private_key == "":
-                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                GlobalLabelParameters.PRIVATE_KEY_EMPTY,
-                                                                               mconfig)
+                                                                               self.log_config)
 
         # This process ensures that merchant_keyid and merchant_secretkey are mandatory in case of HTTP
         # And displays warning if key alias ,key_password,key_filepath,keyfilename are not present when
@@ -293,85 +236,85 @@ class MerchantConfiguration:
         if type(self.authentication_type) == str:
             if self.authentication_type.lower() == GlobalLabelParameters.HTTP.lower():
                 if self.merchant_id is None or self.merchant_id == "":
-                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                GlobalLabelParameters.MERCHANTID_REQ,
-                                                                               mconfig)
+                                                                               self.log_config)
                 
                 if self.merchant_keyid is None or self.merchant_keyid == "":
-                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                        GlobalLabelParameters.MERCHANT_KEY_ID_REQ,
-                                                                                       mconfig)
+                                                                                       self.log_config)
 
                 if self.merchant_secretkey is None or self.merchant_secretkey == "":
-                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                        GlobalLabelParameters.MERCHANT_SECRET_KEY_REQ,
-                                                                                       mconfig)
+                                                                                       self.log_config)
 
             elif self.authentication_type.lower() == GlobalLabelParameters.JWT.lower():
                 if self.merchant_id is None or self.merchant_id == "":
-                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                GlobalLabelParameters.MERCHANTID_REQ,
-                                                                               mconfig)
+                                                                               self.log_config)
                 
                 if self.key_alias is None or self.key_alias == "":
                     self.key_alias = self.merchant_id
-                    authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_default_values(self.logger,
                                                                                  GlobalLabelParameters.KEY_ALIAS_NULL_EMPTY,
-                                                                                 mconfig)
+                                                                                 self.log_config)
                 if not (self.key_alias == self.merchant_id):
                     self.key_alias = self.merchant_id
-                    authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_default_values(self.logger,
                                                                                  GlobalLabelParameters.INVALID_KEY_ALIAS,
-                                                                                 mconfig)
+                                                                                 self.log_config)
 
                 if self.key_password is None or self.key_password == "":
                     self.key_password = self.merchant_id
-                    authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_default_values(self.logger,
                                                                                  GlobalLabelParameters.KEY_PASSWORD_EMPTY,
-                                                                                 mconfig)
+                                                                                 self.log_config)
 
                 if self.key_file_path is None or self.key_file_path == "":
                     self.key_file_path = GlobalLabelParameters.DEFAULT_KEY_FILE_PATH
-                    authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_default_values(self.logger,
                                                                                  GlobalLabelParameters.KEY_DIRECTORY_EMPTY + self.key_file_path,
-                                                                                 mconfig)
+                                                                                 self.log_config)
 
                 if self.key_file_name is None or self.key_file_name == "":
                     self.key_file_name = self.merchant_id
 
-                    authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_default_values(self.logger,
                                                                                  GlobalLabelParameters.KEY_FILE_EMPTY,
-                                                                                 mconfig)
+                                                                                 self.log_config)
 
             elif self.authentication_type.lower() == GlobalLabelParameters.OAUTH.lower():                
                 if self.access_token is None or self.access_token == "":
-                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                GlobalLabelParameters.ACCESS_TOKEN_EMPTY,
-                                                                               mconfig)
+                                                                               self.log_config)
             
                 if self.ssl_client_cert is None or self.ssl_client_cert == "":
-                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                GlobalLabelParameters.REFRESH_TOKEN_EMPTY,
-                                                                               mconfig)
+                                                                               self.log_config)
             
             elif self.authentication_type.lower() == GlobalLabelParameters.MUTUAL_AUTH.lower():                
                 if self.client_id is None or self.client_id == "":
-                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                GlobalLabelParameters.CLIENT_ID_EMPTY,
-                                                                               mconfig)
+                                                                               self.log_config)
             
                 if self.client_secret is None or self.client_secret == "":
-                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                GlobalLabelParameters.CLIENT_SECRET_EMPTY,
-                                                                               mconfig)
+                                                                               self.log_config)
         else:
-            authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
+            authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(self.logger,
                                                                                GlobalLabelParameters.AUTH_ERROR,
-                                                                               mconfig)
+                                                                               self.log_config)
 
         log_items = GlobalLabelParameters.HIDE_MERCHANT_CONFIG_PROPS
         # This displays the logic for logging all cybs.json values
-        if self.enable_log is True:
+        if self.log_config.enable_log is True:
             for key, value in list(details.items()):
                 if key in log_items:
                     del details[key]
@@ -379,4 +322,4 @@ class MerchantConfiguration:
                 for keys, values in list(details.items()):
                     details[keys] = str(values)
 
-            logger.info("Mconfig >      " + str(ast.literal_eval(json.dumps(details))))
+            self.logger.info("Mconfig >      " + str(ast.literal_eval(json.dumps(details))))
